@@ -13,6 +13,6 @@ def factorial(n: int) -> int:
 	return total
 
 
-def sum(*args):	return sum(args)
-def max(*args):	return max(args)
-def min(*args):	return min(args)
+def _sum(*args):	return sum(args)
+def _max(*args):	return max(args)
+def _min(*args):	return min(args)
